Release 1.2.1
=============

This is a minor release that fixes one bug and adds documentation.

Documentation
-------------

 - Added quickstart guide.
 
 - Removed references to plankton.
 

Bug fixes
---------

 - Improved exception handling for module imports
